@@ -1,4 +1,4 @@
-from typing import List, Tuple, Union
+from typing import List, Tuple, Union, Any
 from pathlib import Path
 from threading import Semaphore
 from concurrent.futures import ThreadPoolExecutor, as_completed
@@ -8,7 +8,11 @@ from baidupcs_py.common.path import walk, join_path
 from baidupcs_py.common.crypto import calu_file_md5
 from baidupcs_py.common.concurrent import sure_release
 from baidupcs_py.common.constant import CPU_NUM
-from baidupcs_py.commands.upload import upload as _upload, DEFAULT_SLICE_SIZE
+from baidupcs_py.commands.upload import (
+    upload as _upload,
+    EncryptType,
+    DEFAULT_SLICE_SIZE,
+)
 
 from rich import print
 
@@ -38,6 +42,9 @@ def sync(
     api: BaiduPCSApi,
     localdir: str,
     remotedir: str,
+    encrypt_key: Any = None,
+    salt: Any = None,
+    encrypt_type: EncryptType = EncryptType.No,
     max_workers: int = CPU_NUM,
     slice_size: int = DEFAULT_SLICE_SIZE,
     show_progress: bool = True,
@@ -85,6 +92,9 @@ def sync(
     _upload(
         api,
         fts,
+        encrypt_key=encrypt_key,
+        salt=salt,
+        encrypt_type=encrypt_type,
         max_workers=max_workers,
         slice_size=slice_size,
         ignore_existing=False,
